<?php

/*
Plugin Name: Rel Nofollow Categories
Version: 1.1
Description: This SEO plugin inserts "nofollow" rel attribute to category links generated by the_category and  wp_list_categories
Author: Marvie Pons
Author URI: http://triptripper.com/
Donate URI: http://tutorials.triptripper.com/
Plugin URI: http://tutorials.triptripper.com/rel-nofollow-categories-wordpress-plugin/
  
Copyright 2012  Marvie Pons (email: celebritybanderas@gmail.com)

Released under GPL License.
*/

define('RNC_VERSION', '1.1');

// REQUIRE MINIMUM VERSION OF WORDPRESS:                                               

function rnc_requires_wordpress_version() {
	global $wp_version;
	$plugin = plugin_basename( __FILE__ );
	$plugin_data = get_plugin_data( __FILE__, false );

	if ( version_compare($wp_version, "2.8", "<" ) ) {
		if( is_plugin_active($plugin) ) {
			deactivate_plugins( $plugin );
			wp_die( "'".$plugin_data['Name']."' requires WordPress 2.8 or higher, and has been deactivated! Please upgrade WordPress and try again.<br /><br />Back to <a href='".admin_url()."'>WordPress admin</a>." );
		}
	}
}
add_action( 'admin_init', 'rnc_requires_wordpress_version' );

// Set-up Action and Filter Hooks
register_activation_hook(__FILE__, 'rnc_add_defaults');
register_uninstall_hook(__FILE__, 'rnc_delete_plugin_options');
add_action('admin_init', 'rnc_init' );
add_action('admin_menu', 'rnc_add_options_page');
add_filter( 'plugin_action_links', 'rnc_plugin_action_links', 10, 2 );

// Delete options table entries ONLY when plugin deactivated AND deleted
function rnc_delete_plugin_options() {
	delete_option('rnc_options');
}

// Define default option settings
function rnc_add_defaults() {
	$tmp = get_option('rnc_options');
    if(($tmp['chk_default_options_db']=='1')||(!is_array($tmp))) {
		delete_option('rnc_options'); // so we don't have to reset all the 'off' checkboxes too! (don't think this is needed but leave for now)
		$arr = array(	"chk_button1" => ""
		);
		update_option('rnc_options', $arr);
	}
}

// Init plugin options to white list our options
function rnc_init(){
	register_setting( 'rnc_plugin_options', 'rnc_options', 'rnc_validate_options' );
}

// Add menu page
function rnc_add_options_page() {
	add_options_page('Rel Nofollow Categories', 'Nofollow Categories', 'manage_options', 'rnc_settings_link', 'rnc_render_form');
}

// Render the Plugin options form
function rnc_render_form() {
	?>
	<div class="wrap">
	
	<!-- Display Plugin Icon, Header, and Description -->
	
	<div class="icon32" id="icon-options-general"><br></div>
	<h2>Rel Nofollow Categories v<?php echo RNC_VERSION; ?></h2>
	
	<!-- Side Info Column -->
	
	<div id="poststuff" class="metabox-holder has-right-sidebar">
	
		<!-- Plugin Options Column -->

		<div id="post-body" class="has-sidebar">
			<div id="post-body-content" class="has-sidebar-content">
				<div id="normal-sortables" class="meta-box-sortables">
					<div id="about" class="postbox">
						<div class="inside">		
		

		<!-- Beginning of the Plugin Options Form -->
		<form method="post" action="options.php">
			<?php settings_fields('rnc_plugin_options'); ?>
			<?php $options = get_option('rnc_options'); ?>

			<!-- Table Structure Containing Form Controls -->
			<!-- Each Plugin Option Defined on a New Table Row -->
			<table class="form-table">
				
				<!-- Checkbox Buttons -->
				<tr valign="top">
					<th scope="row">Noindex</th>
					<td>
						<label><input name="rnc_options[chk_button1]" type="checkbox" value="1" <?php if (isset($options['chk_button1'])) { checked('1', $options['chk_button1']); } ?> /> Add noindex meta tag to category pages.</label>							
					</td>
				</tr>				
				
				<tr><td colspan="2"><div style="margin-top:10px;"></div></td></tr>
				<tr valign="top" style="border-top:#dddddd 1px solid;">
					<th scope="row">Database Options</th>
					<td>
						<label><input name="rnc_options[chk_default_options_db]" type="checkbox" value="1" <?php if (isset($options['chk_default_options_db'])) { checked('1', $options['chk_default_options_db']); } ?> /> Restore defaults upon plugin deactivation/reactivation</label>
						<br /><span style="color:#666666;margin-left:2px;">Only check this if you want to reset plugin settings upon Plugin reactivation</span>
					</td>
				</tr>
			</table>
			<input type="submit" class="button-primary" value="<?php _e('Save Changes') ?>" />

		</form>

			<br class="clear" />
						</div>
					</div>
				</div>
			</div>
		</div>
	
			<div id="side-info-column" class="inner-sidebar">
			<div class="meta-box-sortables">
				<div id="about" class="postbox">
					<h3 class="hndle" id="about-sidebar">About the Plugin:</h3>
					<div class="inside">
						<p>You are using <a href="http://tutorials.triptripper.com/rel-nofollow-categories-wordpress-plugin/" target="_blank" style="color:#72a1c6;"><strong>Rel Nofollow Categories</strong></a> Plugin v<?php echo RNC_VERSION; ?></p>
					</div>
				</div>
			</div>	
			
				<div id="about" class="postbox">
					<h3 class="hndle" id="about-sidebar">Enjoy the plugin?</h3>
					<div class="inside">		
						Why not consider <a href="http://wordpress.org/extend/plugins/rel-nofollow-categories/" target="_blank">giving it a good rating on WordPress.org</a> or <a href="http://twitter.com/?status=Rel Nofollow Categories plugin for WordPress - check it out! http://tutorials.triptripper.com/?p=42" target="_blank">Tweet about it</a>. Thanks.</p>
									<span><a href="http://www.facebook.com/pages/How-To-Tutorials-Triptrip-Tips/233542810083158" title="Our Facebook page" target="_blank"><img style="border:1px #ccc solid;" src="<?php echo plugins_url(); ?>/rel-nofollow-categories/images/facebook-icon.png" /></a></span>
									&nbsp;&nbsp;<span><a href="http://twitter.com/Triptrippertips" title="Follow on Twitter" target="_blank"><img style="border:1px #ccc solid;" src="<?php echo plugins_url(); ?>/rel-nofollow-categories/images/twitter-icon.png" /></a></span>
									&nbsp;&nbsp;<span><a href="http://tutorials.triptripper.com/" title="Tutorials.Triptripper.com" target="_blank"><img style="border:1px #ccc solid;" src="<?php echo plugins_url(); ?>/rel-nofollow-categories/images/pc-icon.png" /></a></span>
					</div>
				</div>

			<div id="about" class="postbox">
				<h3 class="hndle" id="about-sidebar">Donate:</h3>
				<div class="inside">
					<p>If you have found this plugin at all useful, please consider buying me a cup of coffee. Thank you!<br />
					<form action="https://www.paypal.com/cgi-bin/webscr" method="post">
					<input type="hidden" name="cmd" value="_s-xclick">
					<input type="hidden" name="hosted_button_id" value="ZVBUFAT97FY4C">
					<input type="image" src="https://www.paypalobjects.com/en_US/i/btn/btn_donate_LG.gif" border="0" name="submit" alt="PayPal - The safer, easier way to pay online!">
					<img alt="" border="0" src="https://www.paypalobjects.com/en_US/i/scr/pixel.gif" width="1" height="1">
					</form></p>
				</div>
			</div>
			
			</div>	
		
		</div>			
	</div>
	<?php	
}

// Sanitize and validate input
function rnc_validate_options($input) {
	if ( ! isset( $input['chk_button1'] ) )
		$input['chk_button1'] = null;
	$input['chk_button1'] = ( $input['chk_button1'] == 1 ? 1 : 0 );
	return $input;
}



// Display a Settings link on the main Plugins page
function rnc_plugin_action_links( $links, $file ) {

	if ( $file == plugin_basename( __FILE__ ) ) {
		$rnc_links = '<a href="'.get_admin_url().'options-general.php?page=rnc_settings_link">'.__('Settings').'</a>';
		// make the 'Settings' link appear first
		array_unshift( $links, $rnc_links );
	}

	return $links;
}

// ------------------------------------------------------------------------------
// OUR PLUGIN FUNCTIONS:
// ------------------------------------------------------------------------------


add_filter( 'wp_list_categories', 'adding_nofollow' );
add_filter( 'the_category', 'adding_nofollow_cat' );

function adding_nofollow( $text ) {
	
	$text = stripslashes($text);
	$text = preg_replace_callback('|<a (.+?)>|i', 'wp_rel_nofollow_callback', $text);
	return $text;
}

function adding_nofollow_cat( $text ) {
	
	$text = str_replace('rel="category tag"', "", $text);
	$text = adding_nofollow($text);
	return $text;
}

function adding_noindex_cat() {
$options = get_option('rnc_options');
if ( isset($options['chk_button1']) && ($options['chk_button1']!="") ) {
  		if (is_category() && !is_feed()) {
			echo "\n<!-- Meta tag added by Rel Nofollow Categories: http://tutorials.triptripper.com/rel-nofollow-categories-wordpress-plugin/ -->\n";
			echo '<meta name="robots" content="noindex" />';
			echo "\n<!-- Rel Nofollow Categories end -->\n";
		} 
	}
}

add_action('wp_head', 'adding_noindex_cat');

?>
